@@ -95,22 +95,3 @@ NULL
   }
   invisible()
 }
-
-#' Example application to HMM likelihood
-#'
-#' @description
-#' This object is saved for reproducibility and to save computation time when
-#' building the vignettes.
-#'
-#' See the vignette about the HMM likelihood for details on how this object was
-#' built: <https://loelschlaeger.de/ino/articles/example_hmm.html>
-#'
-#' @docType data
-#'
-#' @usage data("Nop_hmm")
-#'
-#' @format
-#' A \code{\link{Nop}} object.
-#'
-#' @keywords internal
-"Nop_hmm"
